==> skrooge_0.6.0.orig.tar.gz: skrooge-0.6.0/tests/suite_squish/tst_debug/test.py <==
def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initSimple()

    waitForObject(":kContextList_QScrollBar_2")
    scrollTo(":kContextList_QScrollBar_2", 400)
    waitForObject(":kContextList.Debug_ListWidgetItem")
    mouseClick(":kContextList.Debug_ListWidgetItem", 142, 30, 0, Qt.LeftButton)
    waitForObject(":Skrooge debug plugin.Execute SQL command_KPushButton")
    clickButton(":Skrooge debug plugin.Execute SQL command_KPushButton")
    waitForObject(":Skrooge debug plugin.Execute SQL command in a transaction_KPushButton")
    clickButton(":Skrooge debug plugin.Execute SQL command in a transaction_KPushButton")
    waitForObject(":Skrooge debug plugin.Refresh Database_KPushButton")
    clickButton(":Skrooge debug plugin.Refresh Database_KPushButton")
    waitForObject(":Skrooge debug plugin.kExplainCmb_SKGComboBox")
    sendEvent("QWheelEvent", ":Skrooge debug plugin.kExplainCmb_SKGComboBox", 55, 8, -120, 0, 2)
    waitForObject(":Skrooge debug plugin.Execute SQL command_KPushButton")
    clickButton(":Skrooge debug plugin.Execute SQL command_KPushButton")
    waitForObject(":Skrooge debug plugin.kExplainCmb_SKGComboBox")
    sendEvent("QWheelEvent", ":Skrooge debug plugin.kExplainCmb_SKGComboBox", 92, 6, -120, 0, 2)
    waitForObject(":Skrooge debug plugin.Execute SQL command_KPushButton")
    clickButton(":Skrooge debug plugin.Execute SQL command_KPushButton")
    waitForObject(":kTraceLevel_QSlider")
    scrollTo(":kTraceLevel_QSlider", 19)
    waitForObject(":Skrooge debug plugin.Enable profiling_QCheckBox")
    clickButton(":Skrooge debug plugin.Enable profiling_QCheckBox")
    waitForObject(":Skrooge debug plugin.Enable profiling_QCheckBox")
    clickButton(":Skrooge debug plugin.Enable profiling_QCheckBox")
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":Untitled [modified] - skrooge_SKGMainPanel")
    waitForObject(":Question – Skrooge.Do not save_KPushButton")
    clickButton(":Question – Skrooge.Do not save_KPushButton")

==> skrooge_0.7.2.2.orig.tar.gz: skrooge-0.7.2.2/tests/suite_squish/tst_debug/test.py <==
def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initSimple()

    type(waitForObject(":Untitled - skrooge_KTabBar"), "<Ctrl+Alt+2>")
    waitForObject(":Skrooge debug plugin.Execute SQL command_KPushButton")
    clickButton(":Skrooge debug plugin.Execute SQL command_KPushButton")
    waitForObject(":Skrooge debug plugin.Execute SQL command in a transaction_KPushButton")
    clickButton(":Skrooge debug plugin.Execute SQL command in a transaction_KPushButton")
    waitForObject(":Skrooge debug plugin.Refresh Database_KPushButton")
    clickButton(":Skrooge debug plugin.Refresh Database_KPushButton")
    waitForObject(":Skrooge debug plugin.kExplainCmb_SKGComboBox")
    sendEvent("QWheelEvent", ":Skrooge debug plugin.kExplainCmb_SKGComboBox", 55, 8, -120, 0, 2)
    waitForObject(":Skrooge debug plugin.Execute SQL command_KPushButton")
    clickButton(":Skrooge debug plugin.Execute SQL command_KPushButton")
    waitForObject(":Skrooge debug plugin.kExplainCmb_SKGComboBox")
    sendEvent("QWheelEvent", ":Skrooge debug plugin.kExplainCmb_SKGComboBox", 92, 6, -120, 0, 2)
    waitForObject(":Skrooge debug plugin.Execute SQL command_KPushButton")
    clickButton(":Skrooge debug plugin.Execute SQL command_KPushButton")
    waitForObject(":kTraceLevel_QSlider")
    scrollTo(":kTraceLevel_QSlider", 19)
    waitForObject(":Skrooge debug plugin.Enable profiling_QCheckBox")
    clickButton(":Skrooge debug plugin.Enable profiling_QCheckBox")
    waitForObject(":Skrooge debug plugin.Enable profiling_QCheckBox")
    clickButton(":Skrooge debug plugin.Enable profiling_QCheckBox")
    
    snooze(1)
    
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":Untitled [modified] - skrooge_SKGMainPanel")
    waitForObject(":Question – Skrooge.Do not save_KPushButton")
    clickButton(":Question – Skrooge.Do not save_KPushButton")
